@@ -14,8 +14,8 @@ class DefaultReviewers(BitbucketCloudBase):
         return DefaultReviewer(
             self.url_joiner(self.url, data["uuid"]),
             data,
-            **self._new_session_args,
-        )
+            **self._new_session_args
+        )  # fmt: skip
 
     def add(self, user):
         """
