@@ -249,8 +249,8 @@ class AtlassianRestAPI(object):
         )
         response.encoding = "utf-8"
 
-        log.debug("HTTP: {} {} -> {} {}".format(method, path, response.status_code, response.reason))
-        log.debug("HTTP: Response text -> {}".format(response.text))
+        log.debug("HTTP: %s %s -> %s %s", method, path, response.status_code, response.reason)
+        log.debug("HTTP: Response text -> %s", response.text)
         if self.advanced_mode or advanced_mode:
             return response
 
